// java wrapper for vtkColorTransferFunctionItem object
//

package vtk;
import vtk.*;

public class vtkColorTransferFunctionItem extends vtkScalarsToColorsItem
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetColorTransferFunction_2(vtkColorTransferFunction id0);
  public void SetColorTransferFunction(vtkColorTransferFunction id0)
    { SetColorTransferFunction_2(id0); }

  private native long GetColorTransferFunction_3();
  public vtkColorTransferFunction GetColorTransferFunction() {
    long temp = GetColorTransferFunction_3();

    if (temp == 0) return null;
    return (vtkColorTransferFunction)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkColorTransferFunctionItem() { super(); }

  public vtkColorTransferFunctionItem(long id) { super(id); }
  public native long   VTKInit();

}
